==> fargatestepfunctions-1.166.1-sources.jar: software/amazon/awsconstructs/services/fargatestepfunctions/FargateToStepfunctions.java <==
package software.amazon.awsconstructs.services.fargatestepfunctions;

@javax.annotation.Generated(value = "jsii-pacmak/1.63.2 (build a8a8833)", date = "2022-08-10T02:30:27.199Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.fargatestepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-fargate-stepfunctions.FargateToStepfunctions")
public class FargateToStepfunctions extends software.amazon.awscdk.core.Construct {

    protected FargateToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected FargateToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    public FargateToStepfunctions(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition getContainer() {
        return software.amazon.jsii.Kernel.get(this, "container", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.ContainerDefinition.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.FargateService getService() {
        return software.amazon.jsii.Kernel.get(this, "service", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.FargateService.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctionsProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctionsProps.Builder();
        }

        /**
         * Whether the construct is deploying a private or public API.
         * <p>
         * This has implications for the VPC deployed
         * by this construct.
         * <p>
         * Default: - none
         * <p>
         * @return {@code this}
         * @param publicApi Whether the construct is deploying a private or public API. This parameter is required.
         */
        public Builder publicApi(final java.lang.Boolean publicApi) {
            this.props.publicApi(publicApi);
            return this;
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Optional properties to create a new ECS cluster.
         * <p>
         * @return {@code this}
         * @param clusterProps Optional properties to create a new ECS cluster. This parameter is required.
         */
        public Builder clusterProps(final software.amazon.awscdk.services.ecs.ClusterProps clusterProps) {
            this.props.clusterProps(clusterProps);
            return this;
        }

        /**
         * @return {@code this}
         * @param containerDefinitionProps This parameter is required.
         */
        public Builder containerDefinitionProps(final java.lang.Object containerDefinitionProps) {
            this.props.containerDefinitionProps(containerDefinitionProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * The version of the image to use from the repository.
         * <p>
         * Default: - 'latest'
         * <p>
         * @return {@code this}
         * @param ecrImageVersion The version of the image to use from the repository. This parameter is required.
         */
        public Builder ecrImageVersion(final java.lang.String ecrImageVersion) {
            this.props.ecrImageVersion(ecrImageVersion);
            return this;
        }

        /**
         * The arn of an ECR Repository containing the image to use to generate the containers.
         * <p>
         * format:
         * arn:aws:ecr:[region]:[account number]:repository/[Repository Name]
         * <p>
         * @return {@code this}
         * @param ecrRepositoryArn The arn of an ECR Repository containing the image to use to generate the containers. This parameter is required.
         */
        public Builder ecrRepositoryArn(final java.lang.String ecrRepositoryArn) {
            this.props.ecrRepositoryArn(ecrRepositoryArn);
            return this;
        }

        /**
         * @return {@code this}
         * @param existingContainerDefinitionObject This parameter is required.
         */
        public Builder existingContainerDefinitionObject(final software.amazon.awscdk.services.ecs.ContainerDefinition existingContainerDefinitionObject) {
            this.props.existingContainerDefinitionObject(existingContainerDefinitionObject);
            return this;
        }

        /**
         * A Fargate Service already instantiated (probably by another Solutions Construct).
         * <p>
         * If
         * this is specified, then no props defining a new service can be provided, including:
         * existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps,
         * ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value
         * is provided, then existingContainerDefinitionObject must be provided as well.
         * <p>
         * Default: - none
         * <p>
         * @return {@code this}
         * @param existingFargateServiceObject A Fargate Service already instantiated (probably by another Solutions Construct). This parameter is required.
         */
        public Builder existingFargateServiceObject(final software.amazon.awscdk.services.ecs.FargateService existingFargateServiceObject) {
            this.props.existingFargateServiceObject(existingFargateServiceObject);
            return this;
        }

        /**
         * An existing VPC in which to deploy the construct.
         * <p>
         * Providing both this and
         * vpcProps is an error. If the client provides an existing Fargate service,
         * this value must be the VPC where the service is running. A Step Functions Interface
         * endpoint will be added to this VPC.
         * <p>
         * Default: - none
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC in which to deploy the construct. This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here.
         * <p>
         * defaults - fargate-defaults.ts
         * <p>
         * @return {@code this}
         * @param fargateServiceProps Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. This parameter is required.
         */
        public Builder fargateServiceProps(final java.lang.Object fargateServiceProps) {
            this.props.fargateServiceProps(fargateServiceProps);
            return this;
        }

        /**
         * @return {@code this}
         * @param fargateTaskDefinitionProps This parameter is required.
         */
        public Builder fargateTaskDefinitionProps(final java.lang.Object fargateTaskDefinitionProps) {
            this.props.fargateTaskDefinitionProps(fargateTaskDefinitionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * Optional Name for the container environment variable set to the ARN of the state machine.
         * <p>
         * Default: - STATE_MACHINE_ARN
         * <p>
         * @return {@code this}
         * @param stateMachineEnvironmentVariableName Optional Name for the container environment variable set to the ARN of the state machine. This parameter is required.
         */
        public Builder stateMachineEnvironmentVariableName(final java.lang.String stateMachineEnvironmentVariableName) {
            this.props.stateMachineEnvironmentVariableName(stateMachineEnvironmentVariableName);
            return this;
        }

        /**
         * Optional custom properties for a VPC the construct will create.
         * <p>
         * This VPC will
         * be used by the new Fargate service the construct creates (that's
         * why targetGroupProps can't include a VPC). Providing
         * both this and existingVpc is an error. A Step Functions Interface
         * endpoint will be included in this VPC.
         * <p>
         * Default: - A set of defaults from vpc-defaults.ts: DefaultPublicPrivateVpcProps() for public APIs
         * and DefaultIsolatedVpcProps() for private APIs.
         * <p>
         * @return {@code this}
         * @param vpcProps Optional custom properties for a VPC the construct will create. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions build() {
            return new software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> fargatestepfunctions-2.61.0-sources.jar: software/amazon/awsconstructs/services/fargatestepfunctions/FargateToStepfunctions.java <==
package software.amazon.awsconstructs.services.fargatestepfunctions;

@javax.annotation.Generated(value = "jsii-pacmak/1.101.0 (build b95fe5d)", date = "2024-07-05T20:07:54.580Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.fargatestepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-fargate-stepfunctions.FargateToStepfunctions")
public class FargateToStepfunctions extends software.constructs.Construct {

    protected FargateToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected FargateToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    public FargateToStepfunctions(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition getContainer() {
        return software.amazon.jsii.Kernel.get(this, "container", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.ContainerDefinition.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.FargateService getService() {
        return software.amazon.jsii.Kernel.get(this, "service", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.FargateService.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctionsProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctionsProps.Builder();
        }

        /**
         * Whether the construct is deploying a private or public API.
         * <p>
         * This has implications for the VPC deployed
         * by this construct.
         * <p>
         * @return {@code this}
         * @param publicApi Whether the construct is deploying a private or public API. This parameter is required.
         */
        public Builder publicApi(final java.lang.Boolean publicApi) {
            this.props.publicApi(publicApi);
            return this;
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Optional properties to create a new ECS cluster.
         * <p>
         * @return {@code this}
         * @param clusterProps Optional properties to create a new ECS cluster. This parameter is required.
         */
        public Builder clusterProps(final software.amazon.awscdk.services.ecs.ClusterProps clusterProps) {
            this.props.clusterProps(clusterProps);
            return this;
        }

        /**
         * @return {@code this}
         * @param containerDefinitionProps This parameter is required.
         */
        public Builder containerDefinitionProps(final java.lang.Object containerDefinitionProps) {
            this.props.containerDefinitionProps(containerDefinitionProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * The version of the image to use from the repository.
         * <p>
         * Default: - 'latest'
         * <p>
         * @return {@code this}
         * @param ecrImageVersion The version of the image to use from the repository. This parameter is required.
         */
        public Builder ecrImageVersion(final java.lang.String ecrImageVersion) {
            this.props.ecrImageVersion(ecrImageVersion);
            return this;
        }

        /**
         * The arn of an ECR Repository containing the image to use to generate the containers.
         * <p>
         * format:
         * arn:aws:ecr:[region]:[account number]:repository/[Repository Name]
         * <p>
         * @return {@code this}
         * @param ecrRepositoryArn The arn of an ECR Repository containing the image to use to generate the containers. This parameter is required.
         */
        public Builder ecrRepositoryArn(final java.lang.String ecrRepositoryArn) {
            this.props.ecrRepositoryArn(ecrRepositoryArn);
            return this;
        }

        /**
         * @return {@code this}
         * @param existingContainerDefinitionObject This parameter is required.
         */
        public Builder existingContainerDefinitionObject(final software.amazon.awscdk.services.ecs.ContainerDefinition existingContainerDefinitionObject) {
            this.props.existingContainerDefinitionObject(existingContainerDefinitionObject);
            return this;
        }

        /**
         * A Fargate Service already instantiated (probably by another Solutions Construct).
         * <p>
         * If
         * this is specified, then no props defining a new service can be provided, including:
         * existingImageObject, ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps,
         * ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value
         * is provided, then existingContainerDefinitionObject must be provided as well.
         * <p>
         * Default: - none
         * <p>
         * @return {@code this}
         * @param existingFargateServiceObject A Fargate Service already instantiated (probably by another Solutions Construct). This parameter is required.
         */
        public Builder existingFargateServiceObject(final software.amazon.awscdk.services.ecs.FargateService existingFargateServiceObject) {
            this.props.existingFargateServiceObject(existingFargateServiceObject);
            return this;
        }

        /**
         * An existing VPC in which to deploy the construct.
         * <p>
         * Providing both this and
         * vpcProps is an error. If the client provides an existing Fargate service,
         * this value must be the VPC where the service is running. A Step Functions Interface
         * endpoint will be added to this VPC.
         * <p>
         * Default: - none
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC in which to deploy the construct. This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here.
         * <p>
         * defaults - fargate-defaults.ts
         * <p>
         * @return {@code this}
         * @param fargateServiceProps Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. This parameter is required.
         */
        public Builder fargateServiceProps(final java.lang.Object fargateServiceProps) {
            this.props.fargateServiceProps(fargateServiceProps);
            return this;
        }

        /**
         * @return {@code this}
         * @param fargateTaskDefinitionProps This parameter is required.
         */
        public Builder fargateTaskDefinitionProps(final java.lang.Object fargateTaskDefinitionProps) {
            this.props.fargateTaskDefinitionProps(fargateTaskDefinitionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * Optional Name for the container environment variable set to the ARN of the state machine.
         * <p>
         * Default: - STATE_MACHINE_ARN
         * <p>
         * @return {@code this}
         * @param stateMachineEnvironmentVariableName Optional Name for the container environment variable set to the ARN of the state machine. This parameter is required.
         */
        public Builder stateMachineEnvironmentVariableName(final java.lang.String stateMachineEnvironmentVariableName) {
            this.props.stateMachineEnvironmentVariableName(stateMachineEnvironmentVariableName);
            return this;
        }

        /**
         * Optional custom properties for a VPC the construct will create.
         * <p>
         * This VPC will
         * be used by the new Fargate service the construct creates (that's
         * why targetGroupProps can't include a VPC). Providing
         * both this and existingVpc is an error. A Step Functions Interface
         * endpoint will be included in this VPC.
         * <p>
         * Default: - A set of defaults from vpc-defaults.ts: DefaultPublicPrivateVpcProps() for public APIs
         * and DefaultIsolatedVpcProps() for private APIs.
         * <p>
         * @return {@code this}
         * @param vpcProps Optional custom properties for a VPC the construct will create. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions build() {
            return new software.amazon.awsconstructs.services.fargatestepfunctions.FargateToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
